2. The GeologicalToolbox API reference — Geological Toolbox 0.1.0b documentation

# 2. The GeologicalToolbox API reference

## 2.1. Unittest for the ‘GeologicalToolbox.GeoPoint’ class

This is a test module for the Resources.Geometries.GeoPoint class using unittest

class `GeologicalToolbox.tests.test_GeoPoint.` `TestGeoPointClass`(methodName='runTest')

  This is a unittest class for the Resources.Geometries.GeoPoint class

  `setUp`()

    Initialise a temporary database connection for all test cases and fill the database with test data

    Returns: | None

  `tearDown`()

    Empty function, nothing to shutdown after the testing process

    Returns: | Nothing

  `test_add_and_delete_properties`()

    Test the add_property and delete_property function

    Returns: | Nothing
    Raises: | AssertionError – Raises AssertionError if a test fails

  `test_init`()

    Test the initialisation of the database

    Returns: | Nothing
    Raises: | AssertionError – Raises AssertionError if a test fails

  `test_loading`()

    Test the loading functions of the GeoPoint class /1/ load all from database /2/ load by name /3/ load in extent

    Returns: | Nothing
    Raises: | AssertionError – Raises AssertionError if a test fails

  `test_setter_and_getter`()

    Test the setter and getter functions of class GeoPoint

    Returns: | Nothing
    Raises: | AssertionError – Raises AssertionError if a test fails

## 2.2. Unittest for the ‘GeologicalToolbox.Line’ class

This is a test module for the Resources.Geometries.Line class using unittest

class `GeologicalToolbox.tests.test_Line.` `TestLineClass`(methodName='runTest')

  This is a unittest class for the Resources.Geometries.Line class

  `setUp`()

    Initialise a temporary database connection for all test cases and fill the database with test data

    Returns: | None

  `test_delete_point`()

    Test the deletion of a point. /1/ the point itself /2/ delete by coordinates /3/ test auto-removal of doubled points after deletion

    Returns: | Nothing
    Raises: | AssertionError – Raises AssertionError if a test fails

  `test_init`()

    Test the initialisation of the database

    Returns: | Nothing
    Raises: | AssertionError – Raises AssertionError if a test fails

  `test_insert_multiple`()

    Test the insertion of multiple points. Although test remove of doubled values in a line.

    Returns: | Nothing
    Raises: | AssertionError – Raises AssertionError if a test fails

  `test_insert_one`()

    Test the insertion of one point. Additionally test get_point_index(point) function

    Returns: | Nothing
    Raises: | AssertionError – Raises AssertionError if a test fails

  `test_loading`()

    Test the different types of loading of lines from the db. Part 1: load all lines from the database Part 2: load line by id Part 3: load lines by name Part 4: load lines with minimal one point in given extent

    Returns: | Nothing
    Raises: | AssertionError – Raises AssertionError if a test fails

  `test_setter_and_getter`()

    Test the setter and getter functions of class Line

    Returns: | Nothing
    Raises: | AssertionError – Raises AssertionError if a test fails

## 2.3. Unittest for the ‘GeologicalToolbox.PropertyLogs’ module

This is a test module for the Resources.PropertyLogs-Module classes using unittests

class `GeologicalToolbox.tests.test_PropLogs.` `TestPropertyClass`(methodName='runTest')

  a unittest for Property class

  `setUp`()

    Initialise a temporary database connection for all test cases and fill the database with test data

    Returns: | None

  `tearDown`()

    Empty function, nothing to shutdown after the testing process

    Returns: | Nothing

  `test_init`()

    Test the initialisation of the class

    Returns: | Nothing
    Raises: | AssertionError – Raises AssertionError if a test fails

  `test_setter_and_getter`()

    Test the setter and getter functionality

    Returns: | Nothing
    Raises: | AssertionError – Raises Assertion Error when a test fails

class `GeologicalToolbox.tests.test_PropLogs.` `TestWellLogClass`(methodName='runTest')

  a unittest for WellLog class

  `setUp`()

    Initialise a temporary database connection for all test cases and fill the database with test data

    Returns: | None

  `tearDown`()

    Empty function, nothing to shutdown after the testing process

    Returns: | Nothing

  `test_WellLogValue_init`()

    Test the initialisation of the database

    Returns: | Nothing
    Raises: | AssertionError – Raises AssertionError if a test fails

  `test_insert_and_delete_logvalue`()

    Test insertion and deletion functionality of class WellLog

    Returns: | Nothing
    Raises: | AssertionError – Raises AssertionError if a test fails

  `test_setter_and_getter`()

    Tests the setter and getter functionality of the WellLogValue class

    Returns: | Nothing
    Raises: | AssertionError – Raises AssertionError if a test fails

class `GeologicalToolbox.tests.test_PropLogs.` `TestWellLogValueClass`(methodName='runTest')

  a unittest for WellLogValue class

  `setUp`()

    Initialise a temporary database connection for all test cases and fill the database with test data

    Returns: | None

  `tearDown`()

    Empty function, nothing to shutdown after the testing process

    Returns: | Nothing

  `test_WellLogValue_init`()

    Test the initialisation of the database

    Returns: | Nothing
    Raises: | AssertionError – Raises AssertionError if a test fails

  `test_setter_and_getter`()

    Tests the setter and getter functionality of the WellLogValue class

    Returns: | Nothing
    Raises: | AssertionError – Raises AssertionError if a test fails

## 2.4. Unittest for the ‘GeologicalToolbox.StratigraphicObject’ module

This is a test module for the Resources.StratigraphicObject.StratigraphicObject class using unittest

## 2.5. Unittest for the ‘GeologicalToolbox.Wells’ module

This is a test module for the Resources.Geometries.Well and WellMarker classes using unittest

class `GeologicalToolbox.tests.test_Well.` `TestWellClass`(methodName='runTest')

  a unittest for Well class

  `setUp`()

    Initialise a temporary database connection for all test cases and fill the database with test data

    Returns: | None

  `tearDown`()

    Empty function, nothing to shutdown after the testing process

    Returns: | Nothing

  `test_delete_marker`()

    Test the Well.get_marker_by_depth function

    Returns: | Nothing
    Raises: | AssertionError – Raises AssertionError if a test fails

  `test_get_marker_by_depth`()

    Test the Well.get_marker_by_depth function

    Returns: | Nothing
    Raises: | AssertionError – Raises AssertionError if a test fails

  `test_init`()

    Test the initialisation of the database

    Returns: | Nothing
    Raises: | AssertionError – Raises AssertionError if a test fails

  `test_insertion`()

    Test the insert functions of class Well

    Returns: | Nothing
    Raises: | AssertionError – Raises AssertionError if a test fails

  `test_loading`()

    Test the different types of loading of lines from the db. Part 1: load all wells from the database Part 2: load well by name Part 3: load wells in given extent Part 4: load wells with minimal depth

    Returns: | Nothing
    Raises: | AssertionError – Raises AssertionError if a test fails

  `test_log_handling`()

    Tests the log handling functionality

    Returns: | Nothing
    Raises: | AssertionError – Raises AssertionError if a test fails

  `test_setter_and_getter`()

    Test setter and getter functionality

    Returns: | Nothing
    Raises: | AssertionError – Raises Assertion Error if a test fails

class `GeologicalToolbox.tests.test_Well.` `TestWellMarkerClass`(methodName='runTest')

  a unittest for WellMarker class

  `setUp`()

    Initialise a temporary database connection for all test cases and fill the database with test data

    Returns: | None

  `tearDown`()

    Empty function, nothing to shutdown after the testing process

    Returns: | Nothing

  `test_WellMarker_init`()

    Test the initialisation of the database

    Returns: | Nothing
    Raises: | AssertionError – Raises AssertionError if a test fails

  `test_WellMarker_setter_and_getter`()

    Test setter and getter functionality

    Returns: | Nothing
    Raises: | AssertionError – Raises Assertion Error if a test fails

  `test_WellMarker_to_GeoPoint`()

    Test WellMarker.to_GeoPoint functionality

    Returns: | Nothing
    Raises: | AssertionError – Raises Assertion Error if a test fails